--[[
        AH_addCustomTaunt
        
        
        A global function that allows you to add a custom taunt if you so desire. I strongly discourage adding a custom taunt to
        your main character wad. What I would instead suggest is that you either make a seperate wad/pk3 that just adds the sound,
        or create a seperate version of your character that includes the needed Lua. Adding support to your main character file 
        will only add niche Lua that breaks record attack support :/
        
        Note that in order for this to work, this mod will need to be loaded BEFORE loading your custom taunts. Can't very well
        call a function that doesn't exist yet, can you? :x
        
        
        Documentation: To add a custom taunt, you only need 1 little line (minimum) of Lua and the sound itself
        
                       Ex:
                       ==================================================================================
                       = AH_addCustomTaunt("sonic", "sfx_tntsnc")                                       =
                       ==================================================================================
        
                       You can also add multiple sounds at once in the same file, which can be useful for character packs.
                       
                       Ex:
                       ==================================================================================
                       = AH_addCustomTaunt("sonic", "sfx_tntsnc")                                       =
                       = AH_addCustomTaunt("tails", "sfx_tnttls")                                       =
                       = AH_addCustomTaunt("knuckles", "sfx_tntkte")                                    =
                       = AH_addCustomTaunt("eggman", "sfx_tntegg")                                      =
                       = AH_addCustomTaunt("metalsonic", "sfx_tntmtl")                                  =
                       ==================================================================================
                       
                       (For the extremely off chance of legacy taunts, backwards compatability exists for the old method)
                       ==================================================================================
                       = freeslot("sfx_tntsnc")                                                         =
                       = AH_addCustomTaunt("sonic", sfx_tntsnc)                                         =
                       ==================================================================================
                       ==================================================================================
                       = freeslot("sfx_tntsnc", "sfx_tnttls", "sfx_tntkte", "sfx_tntegg", "sfx_tntmtl") =
                       = AH_addCustomTaunt("sonic", sfx_tntsnc)                                         =
                       = AH_addCustomTaunt("tails", sfx_tnttls)                                         =
                       = AH_addCustomTaunt("knuckles", sfx_tntkte)                                      =
                       = AH_addCustomTaunt("eggman", sfx_tntegg)                                        =
                       = AH_addCustomTaunt("metalsonic", sfx_tntmtl)                                    =
                       ==================================================================================
        
            For WADs: Add your sound effect and Lua file to your wad in a wad editor (such as SLADE).
                  
                      Your sound effect must be prefixed as DS<NAME>, where <NAME> is any 1-6 character name. The name itself should
                      match the sound effect you're allocating in the script (Ex: DSTNTSNC = "sfx_tntsnc"). Most of you wad makers are
                      likely already aware of how these work.
                  
                      Your Lua file must be prefixed as LUA_NAME, where NAME is any 1-4 character name.
                  
            For PK3s: Add your sound effect under the Sounds/ directory, and your Lua file under the Lua/ directory using a supported editor
        
                      Like with WADs, your sound effect must be prefixed as DS<NAME>, where <NAME> is any 1-6 character name and
                      should match the sound you're allocating.
                  
                      For PK3s, Lua files can be named however you like, as long as it's under the Lua/ directory. I suggest using
                      some form of kl_<filename>.lua relating to the character you're adding taunts to for both housekeeping and
                      limiting the chance of conflict.
        
            If you've done all of this correctly, loading your wad/pk3 (AFTER LOADING THIS MOD!) will grant said character a unique bump taunt!
        
        
        by Namolos
        Feel free to borrow from this if you wish
]]--

--[[
    Arguments: string, SFX_*/string
      Example: AH_addcustomTaunt("sonic", sfx_tntsnc)
      Example: AH_addcustomTaunt("sonic", "sfx_tntsnc")  -- I figured out how to check allocated sounds. Why must documentation be sparse
--]]
rawset(_G, "AH_addCustomTaunt", function(skin, sound)
    -- check for bad input
    if type(skin) ~= "string"
        print("\x82".."WARNING:".."\x80".." bad argument #1 to 'AH_addcustomTaunt' (string expected, got "..type(skin)..")")
        return
    end
    if type(sound) == "number" or type(sound) == "string"
        local bullshit
    else
        print("\x82".."WARNING:".."\x80".." bad argument #2 to 'AH_addcustomTaunt' (number or string expected, got "..type(sound)..")")
        return
    end
    
    -- define the table if it doesn't exist
    if (AH_customTauntTable == nil)
        rawset(_G, "AH_customTauntTable", {})  -- why define this by default? Waste of memory
    end
    
    -- it works either way, but make sure the sound isn't already allocated
    if type(sound) == "string" and not _G[sound]
        freeslot(sound)
    end
        
    -- make sure this entry doesn't already exist. We don't want to overwrite table entries or create duplicates
    if (AH_customTauntTable[skin] == nil)
        if type(sound) == "number"  -- backwards compat just in case :x
            AH_customTauntTable[skin] = sound
        else
            AH_customTauntTable[skin] = _G[sound]
        end
    else
        print("\x85".."ERROR:".."\x80".." custom taunt already exists for "..skin..". Custom taunt not added!")
        return
    end
    
    print("Added custom bump taunt for "..skin..". Wow, what an asshole!")
end)

-- debug stuff
--[[local function testSound(p, skin)
    if (AH_customTauntTable[skin] ~= nil)
        print("Playing custom taunt for "..skin)
        S_StartSound(server.mo, AH_customTauntTable[skin])
    else
        print(skin.." is not a valid entry")
    end
    
end

COM_AddCommand("testsound", testSound)]]--
